/// <reference types="bn.js" />
import { TokenInfo } from "@solana/spl-token-registry";
import { Creator } from "@metaplex-foundation/mpl-token-metadata";
import { Metaplex } from "@metaplex-foundation/js";
import { Connection, PublicKey } from "@solana/web3.js";
import { BN } from "@project-serum/anchor";
import { RouterSDK } from "../RouterSDK";
import { BigNumber } from "ethers";
import { Asset, ERC721Collection } from "./Types";
export interface TokenMetaData {
    name: string;
    symbol: string;
    uri: string;
    sellerFeeBasisPoints: number;
    creators: Creator[] | null;
}
export declare class SolanaRouterSDK extends RouterSDK {
    connection: Connection;
    ITeleportIDL: any;
    ERC20RouterIDL: any;
    ERC721RouterIDL: any;
    _tokenList: TokenInfo[];
    metaplex: Metaplex;
    constructor(signerOrProvider: any, optionalParams: any);
    /**
     * @param optionalParams
     * @property teleportIDL: object
     * @property ERC20RouterIDL: object
     */
    setParams(optionalParams: any): void;
    allowance(tokenAddress: any, userAddress: any): Promise<void>;
    allowanceLegacy(tokenAddress: any, userAddress: any): Promise<void>;
    approve(tokenAddress: any, amount: any): Promise<void>;
    approveLegacy(): Promise<void>;
    approveMaxInt(tokenAddress: any): Promise<void>;
    approveMaxIntLegacy(): Promise<void>;
    approveNfts(collectionAddress: any): Promise<void>;
    balanceOf(tokenAddress: string | Uint8Array | PublicKey, userAddress: string | Uint8Array | PublicKey): Promise<{
        balance: BigNumber;
        decimals: number;
    }>;
    balanceOfLegacy(tokenAddress: any, userAddress: any): Promise<void>;
    balanceOfMulticall(tokenAddresses: any, userAddress: any): Promise<any[]>;
    balanceOfMulticallV2Legacy(tokenAddresses: any, userAddress: any): Promise<void>;
    claim(transmission: ClaimTransmission): Promise<unknown>;
    private getDappClaimTxs;
    private getERC20ClaimTxsToSign;
    private getERC721ClaimTxsToSign;
    private getTeleportTxsToSign;
    claimLegacy(transfer: any): Promise<void>;
    estimateApproveNfts(collectionAddress: any): Promise<void>;
    estimateClaim(transmission: ClaimTransmission): Promise<number>;
    estimateSendNftTokens(targetChainId: any, assets: any, userAddress: any, fee: any): Promise<number>;
    fixSignatures(signatures: any): void;
    getALBTToken(): Promise<{
        address: string;
        name: string;
        symbol: string;
        decimals: number;
        balance: BigNumber;
    }>;
    getALBTTokenV1(): Promise<void>;
    getALBTTokenLegacy(): Promise<void>;
    getExternalFeeLegacy(): Promise<void>;
    private getERC721EgressTxs;
    getFeeAmountByToken(tokenAddress: any): Promise<void>;
    getFeeTokens(): Promise<any[]>;
    getNativeTokenByWrappedAddress(wrappedTokenAddress: any): Promise<{
        0: any;
        1: any;
        chainId: any;
        "contractAddress:": any;
    }>;
    getNativeTokenByWrappedAddressLegacy(wrappedTokenAddress: any): Promise<{
        chainId: number;
        token: string;
    }>;
    getNFTBridgeFee(): Promise<any>;
    getProxyFeeLegacy(address: any): Promise<void>;
    getServiceFee(): Promise<any>;
    getServiceFeeLegacy(): Promise<void>;
    getTokenDecimals(tokenAddress: string | Uint8Array | PublicKey): Promise<number>;
    getTokenDetails(tokenAddress: string | Uint8Array | PublicKey, userAddress?: string | Uint8Array | PublicKey): Promise<{
        address: string;
        name: string;
        symbol: string;
        decimals: number;
        balance: BigNumber;
    }>;
    getTokenDetailsMulticall(tokenAddresses: Array<string | Uint8Array | PublicKey>, userAddress?: string | Uint8Array | PublicKey): Promise<{
        address: string;
        name: string;
        symbol: string;
        decimals: number;
        balance: BigNumber;
    }[]>;
    getTokenName(tokenAddress: string | Uint8Array | PublicKey): Promise<string>;
    getTokenSymbol(tokenAddress: string | Uint8Array | PublicKey): Promise<string>;
    getWrappedForNativeToken(nativeChainId: number, nativeToken: string): Promise<string>;
    getWrappedTokenDetails(nativeTokenAddress: any, nativeChainId: any): Promise<void>;
    getWrappedTokenDetailsLegacy(nativeTokenAddress: any, nativeChainId: any): Promise<void>;
    isAddress(address: string, limitOnCurve?: boolean): boolean;
    isClaimedLegacy(transfer: any): Promise<void>;
    isClaimedMulticallLegacy(transfers: any): Promise<void>;
    isNftsApproved(userAddress: any, collectionAddress: any): Promise<boolean>;
    isTokenApproved(tokenAddress: any, userAddress: any, threshold: any /** optional */): Promise<boolean>;
    isTokenApprovedLegacy(): Promise<void>;
    loadTokenByAddressAndId(collectionAddress: string, id: string | undefined, userAddress: string | undefined, skipOwnerCheck?: boolean): Promise<any>;
    loadTokensByCollectionAddress(collectionAddress: any): Promise<void>;
    sendErc20(estimateOnly: any, // boolean - true if we need to call estimate gas only
    targetChainId: any, // number
    tokenAddress: any, // address - could be AddressZero when bridging native chain currency
    amount: any, // ethers.BigNumber
    receiverAddress: any, // address
    feeTokenAddress: any, // address - could be AddressZero
    deliveryFeeEstimate: any, // ethers.BigNumber
    deliveryFeeExpiry: any, // number
    deliveryFeeSignature: any): Promise<unknown>;
    sendLegacy(): Promise<void>;
    sendNftTokens(targetChainId: number, assets: Array<Asset>, userAddress: string, fee?: BN): Promise<unknown>;
    sendWithPermitLegacy(): Promise<void>;
    _configValidators(optionalParams: any): Promise<void>;
    private _getAddressPK;
    _getAllUserTokens(userAddress: any): Promise<import("@solana/spl-token").RawAccount[]>;
    _getTokenList(): Promise<TokenInfo[]>;
    _getLegacyMetadata(tokenAddress: string): Promise<{
        name: string;
        symbol: string;
        uri: string;
        sellerFeeBasisPoints: number;
        creators: any;
        collection: any;
    }>;
    _getMetadata(tokenAddressPK: PublicKey): Promise<TokenMetaData | null>;
    _loadNftsByCollectionAndIdMulticall(collections: ERC721Collection[]): Promise<any[]>;
}
